import {
  __name
} from "./chunk-INDHDMU3.mjs";

// src/grid.tsx
import { createVNode as _createVNode, isVNode as _isVNode, mergeProps as _mergeProps } from "vue";
import { defineComponent, computed } from "vue";
import { chakra } from "@chakra-ui/vue-system";
import { filterUndefined, mapResponsive } from "@chakra-ui/utils";
import { SNAO } from "@chakra-ui/vue-utils";
function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !_isVNode(s);
}
__name(_isSlot, "_isSlot");
var CGrid = defineComponent({
  name: "CGrid",
  props: {
    as: {
      type: [String, Object],
      default: "div"
    },
    templateColumns: SNAO,
    gap: SNAO,
    rowGap: SNAO,
    columnGap: SNAO,
    autoFlow: SNAO,
    autoRows: SNAO,
    autoColumns: SNAO,
    templateRows: SNAO,
    templateAreas: SNAO,
    area: SNAO,
    column: SNAO,
    row: SNAO
  },
  setup(props, {
    slots,
    attrs
  }) {
    const styles = computed(() => filterUndefined({
      display: "grid",
      gridArea: props.area,
      gridTemplateAreas: props.templateAreas,
      gridGap: props.gap,
      gridRowGap: props.rowGap,
      gridColumnGap: props.columnGap,
      gridAutoColumns: props.autoColumns,
      gridColumn: props.column,
      gridRow: props.row,
      gridAutoFlow: props.autoFlow,
      gridAutoRows: props.autoRows,
      gridTemplateRows: props.templateRows,
      gridTemplateColumns: props.templateColumns
    }));
    return () => {
      return _createVNode(chakra.div, _mergeProps({
        "as": props.as,
        "__label": "grid",
        "__css": styles.value
      }, attrs), _isSlot(slots) ? slots : {
        default: () => [slots]
      });
    };
  }
});
function spanFn(span) {
  return mapResponsive(span, (value) => value === "auto" ? "auto" : `span ${value}/span ${value}`);
}
__name(spanFn, "spanFn");
var CGridItem = defineComponent({
  name: "CGridItem",
  props: {
    as: {
      type: [String, Object],
      default: "div"
    },
    colSpan: SNAO,
    colStart: SNAO,
    colEnd: SNAO,
    rowStart: SNAO,
    rowEnd: SNAO,
    rowSpan: SNAO
  },
  setup(props, {
    slots,
    attrs
  }) {
    const styles = computed(() => filterUndefined({
      gridColumn: spanFn(props.colSpan),
      gridRow: spanFn(props.rowSpan),
      gridColumnStart: props.colStart,
      gridColumnEnd: props.colEnd,
      gridRowStart: props.rowStart,
      gridRowEnd: props.rowEnd
    }));
    return () => _createVNode(chakra.div, _mergeProps({
      "as": props.as,
      "__label": "grid__item",
      "__css": styles.value
    }, attrs), _isSlot(slots) ? slots : {
      default: () => [slots]
    });
  }
});

export {
  CGrid,
  CGridItem
};
